#
# PySNMP MIB module RFC1253-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RFC1253-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:25:56 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, TimeTicks, Counter64, IpAddress, iso, Unsigned32, Gauge32, Bits, Counter32, ModuleIdentity, ObjectIdentity, MibIdentifier, mib_2, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "TimeTicks", "Counter64", "IpAddress", "iso", "Unsigned32", "Gauge32", "Bits", "Counter32", "ModuleIdentity", "ObjectIdentity", "MibIdentifier", "mib-2", "Integer32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ospf = MibIdentifier((1, 3, 6, 1, 2, 1, 14))
class AreaID(IpAddress):
    pass

class RouterID(IpAddress):
    pass

class Metric(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,65535)

class BigMetric(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,16777215)

class TruthValue(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("true", 1), ("false", 2),)

class Status(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("enabled", 1), ("disabled", 2),)

class Validation(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("valid", 1), ("invalid", 2),)

class PositiveInteger(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,4294967295)

class HelloRange(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,65535)

class UpToMaxAge(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,3600)

class InterfaceIndex(Integer32):
    pass

class DesignatedRouterPriority(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class TOSType(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,31)

ospfGeneralGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 14, 1))
ospfRouterId = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 1), RouterID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfRouterId.setDescription("A 32-bit integer uniquely identifying the router in\n            the Autonomous System.\n\n            By convention, to ensure uniqueness, this should\n            default to the value of one of the router's IP\n            interface addresses.")
ospfAdminStat = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 2), Status()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAdminStat.setDescription("The administrative status of OSPF in the router.  The\n            value 'enabled' denotes that the OSPF Process is active\n            on at least one interface; 'disabled' disables it on\n            all interfaces.")
ospfVersionNumber = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(2,))).clone(namedValues=NamedValues(("version2", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVersionNumber.setDescription('The current version number of the OSPF protocol is 2.')
ospfAreaBdrRtrStatus = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfAreaBdrRtrStatus.setDescription('A flag to note whether this router is an area border\n            router.')
ospfASBdrRtrStatus = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 5), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfASBdrRtrStatus.setDescription('A flag to note whether this router is an Autonomous\n            System border router.')
ospfExternLSACount = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfExternLSACount.setDescription('The number of external (LS type 5) link-state\n            advertisements in the link-state database.')
ospfExternLSACksumSum = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfExternLSACksumSum.setDescription("The 32-bit unsigned sum of the LS checksums of the\n            external link-state advertisements contained in the\n            link-state database.  This sum can be used to determine\n            if there has been a change in a router's link state\n            database, and to compare the link-state database of two\n            routers.")
ospfTOSSupport = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 8), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfTOSSupport.setDescription("The router's support for type-of-service routing.")
ospfOriginateNewLSAs = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfOriginateNewLSAs.setDescription('The number of new link-state advertisements that have\n            been originated.  This number is incremented each time\n            the router originates a new LSA.')
ospfRxNewLSAs = MibScalar((1, 3, 6, 1, 2, 1, 14, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfRxNewLSAs.setDescription('The number of link-state advertisements received\n            determined to be new instantiations.  This number does\n            not include newer instantiations of self-originated\n            link-state advertisements.')
ospfAreaTable = MibTable((1, 3, 6, 1, 2, 1, 14, 2), )
if mibBuilder.loadTexts: ospfAreaTable.setDescription("Information describing the configured parameters and\n            cumulative statistics of the router's attached areas.")
ospfAreaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 2, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfAreaId"))
if mibBuilder.loadTexts: ospfAreaEntry.setDescription("Information describing the configured parameters and\n            cumulative statistics of one of the router's attached\n            areas.")
ospfAreaId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 1), AreaID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAreaId.setDescription('A 32-bit integer uniquely identifying an area.  Area\n            ID 0.0.0.0 is used for the OSPF backbone.')
ospfAuthType = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAuthType.setDescription('The authentication type specified for an area.\n            Additional authentication types may be assigned locally\n            on a per Area basis.')
ospfImportASExtern = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 3), TruthValue().clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfImportASExtern.setDescription("The area's support for importing AS external link-\n            state advertisements.")
ospfSpfRuns = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfSpfRuns.setDescription("The number of times that the intra-area route table\n            has been calculated using this area's link-state\n            database.  This is typically done using Dijkstra's\n            algorithm.")
ospfAreaBdrRtrCount = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfAreaBdrRtrCount.setDescription('The total number of area border routers reachable\n            within this area.  This is initially zero, and is\n            calculated in each SPF Pass.')
ospfASBdrRtrCount = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfASBdrRtrCount.setDescription('The total number of Autonomous System border routers\n            reachable within this area.  This is initially zero,\n            and is calculated in each SPF Pass.')
ospfAreaLSACount = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfAreaLSACount.setDescription("The total number of link-state advertisements in this\n            area's link-state database, excluding AS External\n            LSA's.")
ospfAreaLSACksumSum = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 2, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfAreaLSACksumSum.setDescription("The 32-bit unsigned sum of the link-state\n            advertisements' LS checksums contained in this area's\n            link-state database.  This sum excludes external (LS\n            type 5) link-state advertisements.  The sum can be used\n            to determine if there has been a change in a router's\n            link state database, and to compare the link-state\n            database of two routers.")
ospfStubAreaTable = MibTable((1, 3, 6, 1, 2, 1, 14, 3), )
if mibBuilder.loadTexts: ospfStubAreaTable.setDescription('The set of metrics that will be advertised by a\n            default Area Border Router into a stub area.')
ospfStubAreaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 3, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfStubAreaID"), (0, "RFC1253-MIB", "ospfStubTOS"))
if mibBuilder.loadTexts: ospfStubAreaEntry.setDescription('The metric for a given Type of Service that will be\n            advertised by a default Area Border Router into a stub\n            area.')
ospfStubAreaID = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 3, 1, 1), AreaID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfStubAreaID.setDescription('The 32 bit identifier for the Stub Area.  On creation,\n            this can be derived from the instance.')
ospfStubTOS = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 3, 1, 2), TOSType()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfStubTOS.setDescription('The Type of Service associated with the metric.  On\n            creation, this can be derived from the instance.')
ospfStubMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 3, 1, 3), BigMetric()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfStubMetric.setDescription('The metric value applied at the indicated type of\n            service.  By default, this equals the least metric at\n            the type of service among the interfaces to other\n            areas.')
ospfStubStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 3, 1, 4), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfStubStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfLsdbTable = MibTable((1, 3, 6, 1, 2, 1, 14, 4), )
if mibBuilder.loadTexts: ospfLsdbTable.setDescription("The OSPF Process's Links State Database.")
ospfLsdbEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 4, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfLsdbAreaId"), (0, "RFC1253-MIB", "ospfLsdbType"), (0, "RFC1253-MIB", "ospfLsdbLSID"), (0, "RFC1253-MIB", "ospfLsdbRouterId"))
if mibBuilder.loadTexts: ospfLsdbEntry.setDescription('A single Link State Advertisement.')
ospfLsdbAreaId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 1), AreaID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbAreaId.setDescription('The 32 bit identifier of the Area from which the LSA\n            was received.')
ospfLsdbType = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("routerLink", 1), ("networkLink", 2), ("summaryLink", 3), ("asSummaryLink", 4), ("asExternalLink", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbType.setDescription('The type of the link state advertisement.  Each link\n            state type has a separate advertisement format.')
ospfLsdbLSID = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbLSID.setDescription('The Link State ID is an LS Type Specific field\n            containing either a Router ID or an IP Address; it\n            identifies the piece of the routing domain that is\n            being described by the advertisement.')
ospfLsdbRouterId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 4), RouterID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbRouterId.setDescription('The 32 bit number that uniquely identifies the\n            originating router in the Autonomous System.')
ospfLsdbSequence = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbSequence.setDescription('The sequence number field is a signed 32-bit integer.\n            It is used to detect old and duplicate link state\n            advertisements.  The space of sequence numbers is\n            linearly ordered.  The larger the sequence number the\n            more recent the advertisement.')
ospfLsdbAge = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbAge.setDescription('This field is the age of the link state advertisement\n            in seconds.')
ospfLsdbChecksum = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbChecksum.setDescription("This field is the checksum of the complete contents of\n            the advertisement, excepting the age field.  The age\n            field is excepted so that an advertisement's age can be\n            incremented without updating the checksum.  The\n            checksum used is the same that is used for ISO\n            connectionless datagrams; it is commonly referred to as\n            the Fletcher checksum.")
ospfLsdbAdvertisement = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 4, 1, 8), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfLsdbAdvertisement.setDescription('The entire Link State Advertisement, including its\n            header.')
ospfAreaRangeTable = MibTable((1, 3, 6, 1, 2, 1, 14, 5), )
if mibBuilder.loadTexts: ospfAreaRangeTable.setDescription('A range if IP addresses specified by an IP address/IP\n            network mask pair.  For example, class B address range\n            of X.X.X.X with a network mask of 255.255.0.0 includes\n            all IP addresses from X.X.0.0 to X.X.255.255')
ospfAreaRangeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 5, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfAreaRangeAreaID"), (0, "RFC1253-MIB", "ospfAreaRangeNet"))
if mibBuilder.loadTexts: ospfAreaRangeEntry.setDescription('A range if IP addresses specified by an IP address/IP\n            network mask pair.  For example, class B address range\n            of X.X.X.X with a network mask of 255.255.0.0 includes\n            all IP addresses from X.X.0.0 to X.X.255.255')
ospfAreaRangeAreaID = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 5, 1, 1), AreaID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAreaRangeAreaID.setDescription('The Area the Address Range is to be found within.')
ospfAreaRangeNet = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 5, 1, 2), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAreaRangeNet.setDescription('The IP Address of the Net or Subnet indicated by the\n            range.')
ospfAreaRangeMask = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 5, 1, 3), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAreaRangeMask.setDescription('The Subnet Mask that pertains to the Net or Subnet.')
ospfAreaRangeStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 5, 1, 4), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAreaRangeStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfHostTable = MibTable((1, 3, 6, 1, 2, 1, 14, 6), )
if mibBuilder.loadTexts: ospfHostTable.setDescription('The list of Hosts, and their metrics, that the router\n            will advertise as host routes.')
ospfHostEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 6, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfHostIpAddress"), (0, "RFC1253-MIB", "ospfHostTOS"))
if mibBuilder.loadTexts: ospfHostEntry.setDescription('A metric to be advertised, for a given type of service,\n            when a given host is reachable.')
ospfHostIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 6, 1, 1), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfHostIpAddress.setDescription('The IP Address of the Host.')
ospfHostTOS = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 6, 1, 2), TOSType()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfHostTOS.setDescription('The Type of Service of the route being configured.')
ospfHostMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 6, 1, 3), Metric()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfHostMetric.setDescription('The Metric to be advertised.')
ospfHostStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 6, 1, 4), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfHostStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfIfTable = MibTable((1, 3, 6, 1, 2, 1, 14, 7), )
if mibBuilder.loadTexts: ospfIfTable.setDescription('The OSPF Interface Table describes the interfaces from\n            the viewpoint of OSPF.')
ospfIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 7, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfIfIpAddress"), (0, "RFC1253-MIB", "ospfAddressLessIf"))
if mibBuilder.loadTexts: ospfIfEntry.setDescription('The OSPF Interface Entry describes one interface from\n            the viewpoint of OSPF.')
ospfIfIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 1), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfIpAddress.setDescription('The IP address of this OSPF interface.')
ospfAddressLessIf = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfAddressLessIf.setDescription('For the purpose of easing the instancing of addressed\n            and addressless interfaces; This variable takes the\n            value 0 on interfaces with IP Addresses, and the\n            corresponding value of ifIndex for interfaces having no\n            IP Address.')
ospfIfAreaId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 3), AreaID().clone(hexValue="00000000")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfAreaId.setDescription('A 32-bit integer uniquely identifying the area to\n            which the interface connects.  Area ID 0.0.0.0 is used\n            for the OSPF backbone.')
ospfIfType = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("broadcast", 1), ("nbma", 2), ("pointToPoint", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfType.setDescription("The OSPF interface type.\n\n            By way of a default, this field may be intuited from\n            the corresponding value of ifType.  Broadcast LANs,\n            such as Ethernet and IEEE 802.5, take the value\n            'broadcast', X.25, Frame Relay, and similar\n            technologies take the value 'nbma', and links that are\n            definitively point to point take the value\n            'pointToPoint'.")
ospfIfAdminStat = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 5), Status().clone('enabled')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfAdminStat.setDescription("The OSPF interface's administrative status.  The value\n            'enabled' denotes that neighbor relationships may be\n            formed on the interface, and the interface will be\n            advertised as an internal route to some area.  The\n            value 'disabled' denotes that the interface is external\n            to OSPF.")
ospfIfRtrPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 6), DesignatedRouterPriority().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfRtrPriority.setDescription('The priority of this interface.  Used in multi-access\n            networks, this field is used in the designated router\n            election algorithm.  The value 0 signifies that the\n            router is not eligible to become the designated router\n            on this particular network.  In the event of a tie in\n            this value, routers will use their router id as a tie\n            breaker.')
ospfIfTransitDelay = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 7), UpToMaxAge().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfTransitDelay.setDescription('The estimated number of seconds it takes to transmit a\n            link- state update packet over this interface.')
ospfIfRetransInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 8), UpToMaxAge().clone(5)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfRetransInterval.setDescription('The number of seconds between link-state advertisement\n            retransmissions, for adjacencies belonging to this\n            interface.  This value is also used when retransmitting\n            database description and link-state request packets.')
ospfIfHelloInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 9), HelloRange().clone(10)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfHelloInterval.setDescription('The length of time, in seconds, between the Hello\n            packets that the router sends on the interface.  This\n            value must be the same for all routers attached to a\n            common network.')
ospfIfRtrDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 10), PositiveInteger().clone(40)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfRtrDeadInterval.setDescription("The number of seconds that a router's Hello packets\n            have not been seen before it's neighbors declare the\n            router down.  This should be some multiple of the Hello\n            interval.  This value must be the same for all routers\n            attached to a common network.")
ospfIfPollInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 11), PositiveInteger().clone(120)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfPollInterval.setDescription('The larger time interval, in seconds, between the\n            Hello packets sent to an inactive non-broadcast multi-\n            access neighbor.')
ospfIfState = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("down", 1), ("loopback", 2), ("waiting", 3), ("pointToPoint", 4), ("designatedRouter", 5), ("backupDesignatedRouter", 6), ("otherDesignatedRouter", 7),)).clone('down')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfIfState.setDescription('The OSPF Interface State.')
ospfIfDesignatedRouter = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 13), IpAddress().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfIfDesignatedRouter.setDescription('The IP Address of the Designated Router.')
ospfIfBackupDesignatedRouter = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 14), IpAddress().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfIfBackupDesignatedRouter.setDescription('The IP Address of the Backup Designated Router.')
ospfIfEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfIfEvents.setDescription('The number of times this OSPF interface has changed\n            its state, or an error has occurred.')
ospfIfAuthKey = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 7, 1, 16), OctetString().clone(hexValue="0000000000000000")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfAuthKey.setDescription("The Authentication Key.  If the Area's Authorization\n            Type is simplePassword, and the key length is shorter\n            than 8 octets, the agent will left adjust and zero fill\n            to 8 octets.\n\n            When read, ospfIfAuthKey always returns an Octet String\n            of length zero.")
ospfIfMetricTable = MibTable((1, 3, 6, 1, 2, 1, 14, 8), )
if mibBuilder.loadTexts: ospfIfMetricTable.setDescription('The TOS metrics for a non-virtual interface identified\n            by the interface index.')
ospfIfMetricEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 8, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfIfMetricIpAddress"), (0, "RFC1253-MIB", "ospfIfMetricAddressLessIf"), (0, "RFC1253-MIB", "ospfIfMetricTOS"))
if mibBuilder.loadTexts: ospfIfMetricEntry.setDescription('A particular TOS metric for a non-virtual interface\n            identified by the interface index.')
ospfIfMetricIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 8, 1, 1), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfMetricIpAddress.setDescription('The IP address of this OSPF interface.  On row\n            creation, this can be derived from the instance.')
ospfIfMetricAddressLessIf = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 8, 1, 2), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfMetricAddressLessIf.setDescription('For the purpose of easing the instancing of addressed\n            and addressless interfaces; This variable takes the\n            value 0 on interfaces with IP Addresses, and the value\n            of ifIndex for interfaces having no IP Address.  On row\n            creation, this can be derived from the instance.')
ospfIfMetricTOS = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 8, 1, 3), TOSType()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfMetricTOS.setDescription('The type of service metric being referenced.  On row\n            creation, this can be derived from the instance.')
ospfIfMetricMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 8, 1, 4), Metric()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfMetricMetric.setDescription("The metric of using this type of service on this\n            interface.  The default value of the TOS 0 Metric is\n            10^8 / ifSpeed.\n\n            The value FFFF is distinguished to mean 'no route via\n            this TOS'.")
ospfIfMetricStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 8, 1, 5), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfIfMetricStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfVirtIfTable = MibTable((1, 3, 6, 1, 2, 1, 14, 9), )
if mibBuilder.loadTexts: ospfVirtIfTable.setDescription("Information about this router's virtual interfaces.")
ospfVirtIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 9, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfVirtIfAreaID"), (0, "RFC1253-MIB", "ospfVirtIfNeighbor"))
if mibBuilder.loadTexts: ospfVirtIfEntry.setDescription('Information about a single Virtual Interface.')
ospfVirtIfAreaID = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 1), AreaID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfAreaID.setDescription('The Transit Area that the Virtual Link traverses.  By\n            definition, this is not 0.0.0.0')
ospfVirtIfNeighbor = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 2), RouterID()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfNeighbor.setDescription('The Router ID of the Virtual Neighbor.')
ospfVirtIfTransitDelay = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 3), UpToMaxAge().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfTransitDelay.setDescription('The estimated number of seconds it takes to transmit a\n            link- state update packet over this interface.')
ospfVirtIfRetransInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 4), UpToMaxAge().clone(5)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfRetransInterval.setDescription('The number of seconds between link-state advertisement\n            retransmissions, for adjacencies belonging to this\n            interface.  This value is also used when retransmitting\n            database description and link-state request packets.\n            This value should be well over the expected round-trip\n            time.')
ospfVirtIfHelloInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 5), HelloRange().clone(10)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfHelloInterval.setDescription('The length of time, in seconds, between the Hello\n            packets that the router sends on the interface.  This\n            value must be the same for the virtual neighbor.')
ospfVirtIfRtrDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 6), PositiveInteger().clone(60)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfRtrDeadInterval.setDescription("The number of seconds that a router's Hello packets\n            have not been seen before it's neighbors declare the\n            router down.  This should be some multiple of the Hello\n            interval.  This value must be the same for the virtual\n            neighbor.")
ospfVirtIfState = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 4,))).clone(namedValues=NamedValues(("down", 1), ("pointToPoint", 4),)).clone('down')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtIfState.setDescription('OSPF virtual interface states.')
ospfVirtIfEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtIfEvents.setDescription('The number of state changes or error events on this\n            Virtual Link')
ospfVirtIfAuthKey = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 9), OctetString().clone(hexValue="0000000000000000")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfAuthKey.setDescription('If Authentication Type is simplePassword, the device\n            will left adjust and zero fill to 8 octets.\n\n            When read, ospfVifAuthKey always returns a string of\n            length zero.')
ospfVirtIfStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 9, 1, 10), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfVirtIfStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfNbrTable = MibTable((1, 3, 6, 1, 2, 1, 14, 10), )
if mibBuilder.loadTexts: ospfNbrTable.setDescription('A table of non-virtual neighbor information.')
ospfNbrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 10, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfNbrIpAddr"), (0, "RFC1253-MIB", "ospfNbrAddressLessIndex"))
if mibBuilder.loadTexts: ospfNbrEntry.setDescription('The information regarding a single neighbor.')
ospfNbrIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 1), IpAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfNbrIpAddr.setDescription('The IP address of this neighbor.')
ospfNbrAddressLessIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 2), InterfaceIndex()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfNbrAddressLessIndex.setDescription(' On an interface having an IP Address, zero.  On\n            addressless interfaces, the corresponding value of\n            ifIndex in the Internet Standard MIB.  On row creation,\n            this can be derived from the instance.')
ospfNbrRtrId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 3), RouterID().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfNbrRtrId.setDescription('A 32-bit integer (represented as a type IpAddress)\n            uniquely identifying the neighboring router in the\n            Autonomous System.')
ospfNbrOptions = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfNbrOptions.setDescription("A Bit Mask corresponding to the neighbor's options\n            field.\n\n            Bit 0, if set, indicates that the area accepts and\n            operates on external information; if zero, it is a stub\n            area.\n\n            Bit 1, if set, indicates that the system will operate\n            on Type of Service metrics other than TOS 0.  If zero,\n            the neighbor will ignore all metrics except the TOS 0\n            metric.")
ospfNbrPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 5), DesignatedRouterPriority().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfNbrPriority.setDescription('The priority of this neighbor in the designated router\n            election algorithm.  The value 0 signifies that the\n            neighbor is not eligible to become the designated\n            router on this particular network.')
ospfNbrState = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("down", 1), ("attempt", 2), ("init", 3), ("twoWay", 4), ("exchangeStart", 5), ("exchange", 6), ("loading", 7), ("full", 8),)).clone('down')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfNbrState.setDescription('The State of the relationship with this Neighbor.')
ospfNbrEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfNbrEvents.setDescription('The number of times this neighbor relationship has\n            changed state, or an error has occurred.')
ospfNbrLSRetransQLen = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfNbrLSRetransQLen.setDescription('The current length of the retransmission queue.')
ospfNBMANbrStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 10, 1, 9), Validation().clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ospfNBMANbrStatus.setDescription("This variable displays the validity or invalidity of\n            the entry.  Setting it to 'invalid' has the effect of\n            rendering it inoperative.  The internal effect (row\n            removal) is implementation dependent.")
ospfVirtNbrTable = MibTable((1, 3, 6, 1, 2, 1, 14, 11), )
if mibBuilder.loadTexts: ospfVirtNbrTable.setDescription('A table of virtual neighbor information.')
ospfVirtNbrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 14, 11, 1), ).setIndexNames((0, "RFC1253-MIB", "ospfVirtNbrArea"), (0, "RFC1253-MIB", "ospfVirtNbrRtrId"))
if mibBuilder.loadTexts: ospfVirtNbrEntry.setDescription('Virtual neighbor information.')
ospfVirtNbrArea = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 1), AreaID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrArea.setDescription('The Transit Area Identifier.')
ospfVirtNbrRtrId = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 2), RouterID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrRtrId.setDescription('A 32-bit integer uniquely identifying the neighboring\n            router in the Autonomous System.')
ospfVirtNbrIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrIpAddr.setDescription('The IP address this Virtual Neighbor is using.')
ospfVirtNbrOptions = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrOptions.setDescription("A bit map corresponding to the neighbor's options\n            field.  Thus, Bit 1, if set, indicates that the\n            neighbor supports Type of Service Routing; if zero, no\n            metrics other than TOS 0 are in use by the neighbor.")
ospfVirtNbrState = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("down", 1), ("attempt", 2), ("init", 3), ("twoWay", 4), ("exchangeStart", 5), ("exchange", 6), ("loading", 7), ("full", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrState.setDescription('The state of the Virtual Neighbor Relationship.')
ospfVirtNbrEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrEvents.setDescription('The number of times this virtual link has changed its\n            state, or an error has occurred.')
ospfVirtNbrLSRetransQLen = MibTableColumn((1, 3, 6, 1, 2, 1, 14, 11, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ospfVirtNbrLSRetransQLen.setDescription('The current length of the retransmission queue.')
mibBuilder.exportSymbols("RFC1253-MIB", ospfAreaRangeNet=ospfAreaRangeNet, ospfVirtIfTransitDelay=ospfVirtIfTransitDelay, ospfAreaLSACksumSum=ospfAreaLSACksumSum, ospfIfEvents=ospfIfEvents, ospfVirtIfStatus=ospfVirtIfStatus, ospfLsdbType=ospfLsdbType, ospfStubAreaID=ospfStubAreaID, DesignatedRouterPriority=DesignatedRouterPriority, ospfSpfRuns=ospfSpfRuns, ospfVirtIfRetransInterval=ospfVirtIfRetransInterval, Validation=Validation, ospfRouterId=ospfRouterId, ospfIfTable=ospfIfTable, ospfIfMetricEntry=ospfIfMetricEntry, ospfVirtNbrIpAddr=ospfVirtNbrIpAddr, Metric=Metric, ospfIfDesignatedRouter=ospfIfDesignatedRouter, ospfExternLSACksumSum=ospfExternLSACksumSum, ospfStubStatus=ospfStubStatus, TruthValue=TruthValue, ospfImportASExtern=ospfImportASExtern, ospfLsdbChecksum=ospfLsdbChecksum, ospfOriginateNewLSAs=ospfOriginateNewLSAs, ospfGeneralGroup=ospfGeneralGroup, ospfVirtIfTable=ospfVirtIfTable, ospfLsdbAge=ospfLsdbAge, ospfASBdrRtrStatus=ospfASBdrRtrStatus, ospfNbrLSRetransQLen=ospfNbrLSRetransQLen, ospfIfTransitDelay=ospfIfTransitDelay, ospfIfMetricTable=ospfIfMetricTable, ospfExternLSACount=ospfExternLSACount, ospfIfType=ospfIfType, BigMetric=BigMetric, ospfTOSSupport=ospfTOSSupport, ospfIfMetricTOS=ospfIfMetricTOS, TOSType=TOSType, ospfIfIpAddress=ospfIfIpAddress, ospfIfBackupDesignatedRouter=ospfIfBackupDesignatedRouter, ospfStubAreaEntry=ospfStubAreaEntry, ospfStubAreaTable=ospfStubAreaTable, ospfVirtNbrState=ospfVirtNbrState, ospfNbrIpAddr=ospfNbrIpAddr, ospfVirtNbrEvents=ospfVirtNbrEvents, ospfVersionNumber=ospfVersionNumber, ospfIfPollInterval=ospfIfPollInterval, InterfaceIndex=InterfaceIndex, AreaID=AreaID, ospfIfAreaId=ospfIfAreaId, ospfNbrState=ospfNbrState, ospfLsdbAreaId=ospfLsdbAreaId, ospfNBMANbrStatus=ospfNBMANbrStatus, ospfVirtIfAreaID=ospfVirtIfAreaID, ospfVirtNbrEntry=ospfVirtNbrEntry, ospfIfState=ospfIfState, ospfLsdbEntry=ospfLsdbEntry, ospfAreaRangeEntry=ospfAreaRangeEntry, ospfHostTOS=ospfHostTOS, ospfVirtIfRtrDeadInterval=ospfVirtIfRtrDeadInterval, ospfNbrTable=ospfNbrTable, ospf=ospf, ospfStubMetric=ospfStubMetric, ospfIfRtrDeadInterval=ospfIfRtrDeadInterval, ospfAreaBdrRtrCount=ospfAreaBdrRtrCount, ospfAddressLessIf=ospfAddressLessIf, ospfVirtIfEntry=ospfVirtIfEntry, HelloRange=HelloRange, ospfIfAdminStat=ospfIfAdminStat, ospfIfMetricMetric=ospfIfMetricMetric, ospfAreaRangeAreaID=ospfAreaRangeAreaID, ospfVirtIfNeighbor=ospfVirtIfNeighbor, ospfNbrPriority=ospfNbrPriority, ospfIfRtrPriority=ospfIfRtrPriority, ospfHostMetric=ospfHostMetric, ospfNbrEvents=ospfNbrEvents, ospfLsdbTable=ospfLsdbTable, ospfNbrOptions=ospfNbrOptions, ospfAreaBdrRtrStatus=ospfAreaBdrRtrStatus, ospfAreaLSACount=ospfAreaLSACount, ospfLsdbAdvertisement=ospfLsdbAdvertisement, ospfAreaEntry=ospfAreaEntry, ospfLsdbRouterId=ospfLsdbRouterId, ospfLsdbLSID=ospfLsdbLSID, ospfVirtNbrLSRetransQLen=ospfVirtNbrLSRetransQLen, ospfRxNewLSAs=ospfRxNewLSAs, ospfASBdrRtrCount=ospfASBdrRtrCount, ospfLsdbSequence=ospfLsdbSequence, ospfIfHelloInterval=ospfIfHelloInterval, ospfIfEntry=ospfIfEntry, ospfAuthType=ospfAuthType, ospfVirtIfHelloInterval=ospfVirtIfHelloInterval, ospfVirtNbrRtrId=ospfVirtNbrRtrId, ospfHostEntry=ospfHostEntry, ospfHostTable=ospfHostTable, ospfVirtNbrOptions=ospfVirtNbrOptions, ospfIfRetransInterval=ospfIfRetransInterval, Status=Status, ospfVirtNbrArea=ospfVirtNbrArea, ospfVirtNbrTable=ospfVirtNbrTable, ospfAdminStat=ospfAdminStat, UpToMaxAge=UpToMaxAge, ospfAreaRangeStatus=ospfAreaRangeStatus, ospfAreaRangeTable=ospfAreaRangeTable, ospfHostStatus=ospfHostStatus, ospfVirtIfEvents=ospfVirtIfEvents, ospfIfAuthKey=ospfIfAuthKey, ospfAreaId=ospfAreaId, ospfNbrEntry=ospfNbrEntry, ospfAreaTable=ospfAreaTable, ospfNbrAddressLessIndex=ospfNbrAddressLessIndex, RouterID=RouterID, ospfHostIpAddress=ospfHostIpAddress, ospfIfMetricAddressLessIf=ospfIfMetricAddressLessIf, ospfAreaRangeMask=ospfAreaRangeMask, ospfVirtIfAuthKey=ospfVirtIfAuthKey, PositiveInteger=PositiveInteger, ospfIfMetricStatus=ospfIfMetricStatus, ospfVirtIfState=ospfVirtIfState, ospfIfMetricIpAddress=ospfIfMetricIpAddress, ospfNbrRtrId=ospfNbrRtrId, ospfStubTOS=ospfStubTOS)



#
# PySNMP MIB module RIPv2-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RIPv2-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:26:36 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsIntersection, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( IpAddress, Gauge32, iso, Integer32, mib_2, NotificationType, TimeTicks, Bits, Counter64, ModuleIdentity, ObjectIdentity, Unsigned32, Counter32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Gauge32", "iso", "Integer32", "mib-2", "NotificationType", "TimeTicks", "Bits", "Counter64", "ModuleIdentity", "ObjectIdentity", "Unsigned32", "Counter32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DisplayString")
rip2 = ModuleIdentity((1, 3, 6, 1, 2, 1, 23))
if mibBuilder.loadTexts: rip2.setLastUpdated('9407272253Z')
if mibBuilder.loadTexts: rip2.setOrganization('IETF RIP-II Working Group')
if mibBuilder.loadTexts: rip2.setContactInfo('       Fred Baker\n          Postal: Cisco Systems\n                  519 Lado Drive\n                  Santa Barbara, California 93111\n          Tel:    +1 805 681 0115\n          E-Mail: fbaker@cisco.com\n\n          Postal: Gary Malkin\n                  Xylogics, Inc.\n                  53 Third Avenue\n                  Burlington, MA  01803\n\n          Phone:  (617) 272-8140\n          EMail:  gmalkin@Xylogics.COM')
if mibBuilder.loadTexts: rip2.setDescription('The MIB module to describe the RIP2 Version 2 Protocol')
class RouteTag(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(2,2)
    fixedLength = 2

rip2Globals = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 1))
rip2GlobalRouteChanges = MibScalar((1, 3, 6, 1, 2, 1, 23, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2GlobalRouteChanges.setDescription("The number of route changes made to the IP Route\n           Database by RIP.  This does not include the refresh\n           of a route's age.")
rip2GlobalQueries = MibScalar((1, 3, 6, 1, 2, 1, 23, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2GlobalQueries.setDescription('The number of responses sent to RIP queries\n           from other systems.')
rip2IfStatTable = MibTable((1, 3, 6, 1, 2, 1, 23, 2), )
if mibBuilder.loadTexts: rip2IfStatTable.setDescription('A list of subnets which require separate\n           status monitoring in RIP.')
rip2IfStatEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 2, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2IfStatAddress"))
if mibBuilder.loadTexts: rip2IfStatEntry.setDescription('A Single Routing Domain in a single Subnet.')
rip2IfStatAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatAddress.setDescription('The IP Address of this system on the indicated\n           subnet. For unnumbered interfaces, the value 0.0.0.N,\n           where the least significant 24 bits (N) is the ifIndex\n           for the IP Interface in network byte order.')
rip2IfStatRcvBadPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatRcvBadPackets.setDescription('The number of RIP response packets received by\n           the RIP process which were subsequently discarded\n           for any reason (e.g. a version 0 packet, or an\n           unknown command type).')
rip2IfStatRcvBadRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatRcvBadRoutes.setDescription('The number of routes, in valid RIP packets,\n           which were ignored for any reason (e.g. unknown\n           address family, or invalid metric).')
rip2IfStatSentUpdates = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfStatSentUpdates.setDescription('The number of triggered RIP updates actually\n           sent on this interface.  This explicitly does\n           NOT include full updates sent containing new\n           information.')
rip2IfStatStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 2, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfStatStatus.setDescription('Writing invalid has the effect of deleting\n           this interface.')
rip2IfConfTable = MibTable((1, 3, 6, 1, 2, 1, 23, 3), )
if mibBuilder.loadTexts: rip2IfConfTable.setDescription('A list of subnets which require separate\n           configuration in RIP.')
rip2IfConfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 3, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2IfConfAddress"))
if mibBuilder.loadTexts: rip2IfConfEntry.setDescription('A Single Routing Domain in a single Subnet.')
rip2IfConfAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2IfConfAddress.setDescription('The IP Address of this system on the indicated\n           subnet.  For unnumbered interfaces, the value 0.0.0.N,\n           where the least significant 24 bits (N) is the ifIndex\n           for the IP Interface in network byte order.')
rip2IfConfDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 2), RouteTag().clone(hexValue="0000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfDomain.setDescription('Value inserted into the Routing Domain field\n           of all RIP packets sent on this interface.')
rip2IfConfAuthType = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("noAuthentication", 1), ("simplePassword", 2), ("md5", 3),)).clone('noAuthentication')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfAuthType.setDescription('The type of Authentication used on this\n           interface.')
rip2IfConfAuthKey = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,16)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfAuthKey.setDescription('The value to be used as the Authentication Key\n           whenever the corresponding instance of\n           rip2IfConfAuthType has a value other than\n           noAuthentication.  A modification of the corresponding\n           instance of rip2IfConfAuthType does not modify\n           the rip2IfConfAuthKey value.  If a string shorter\n           than 16 octets is supplied, it will be left-\n           justified and padded to 16 octets, on the right,\n           with nulls (0x00).\n\n           Reading this object always results in an  OCTET\n           STRING of length zero; authentication may not\n           be bypassed by reading the MIB object.')
rip2IfConfSend = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("doNotSend", 1), ("ripVersion1", 2), ("rip1Compatible", 3), ("ripVersion2", 4), ("ripV1Demand", 5), ("ripV2Demand", 6),)).clone('rip1Compatible')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfSend.setDescription('What the router sends on this interface.\n           ripVersion1 implies sending RIP updates compliant\n           with  RFC  1058.   rip1Compatible implies\n           broadcasting RIP-2 updates using RFC 1058 route\n           subsumption rules.  ripVersion2 implies\n           multicasting RIP-2 updates.  ripV1Demand indicates\n           the use of Demand RIP on a WAN interface under RIP\n           Version 1 rules.  ripV2Demand indicates the use of\n           Demand RIP on a WAN interface under Version 2 rules.')
rip2IfConfReceive = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("rip1", 1), ("rip2", 2), ("rip1OrRip2", 3), ("doNotRecieve", 4),)).clone('rip1OrRip2')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfReceive.setDescription('This indicates which version of RIP updates\n           are to be accepted.  Note that rip2 and\n           rip1OrRip2 implies reception of multicast\n           packets.')
rip2IfConfDefaultMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfDefaultMetric.setDescription('This variable indicates the metric that is to\n           be used for the default route entry in RIP updates\n           originated on this interface.  A value of zero\n           indicates that no default route should be\n           originated; in this case, a default route via\n           another router may be propagated.')
rip2IfConfStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 8), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfStatus.setDescription('Writing invalid has  the  effect  of  deleting\n           this interface.')
rip2IfConfSrcAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 3, 1, 9), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rip2IfConfSrcAddress.setDescription('The IP Address this system will use as a source\n            address on this interface.  If it is a numbered\n            interface, this MUST be the same value as\n            rip2IfConfAddress.  On unnumbered interfaces,\n            it must be the value of rip2IfConfAddress for\n            some interface on the system.')
rip2PeerTable = MibTable((1, 3, 6, 1, 2, 1, 23, 4), )
if mibBuilder.loadTexts: rip2PeerTable.setDescription('A list of RIP Peers.')
rip2PeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 23, 4, 1), ).setIndexNames((0, "RIPv2-MIB", "rip2PeerAddress"), (0, "RIPv2-MIB", "rip2PeerDomain"))
if mibBuilder.loadTexts: rip2PeerEntry.setDescription('Information regarding a single routing peer.')
rip2PeerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerAddress.setDescription('The IP Address that the peer is using as its source\n            address.  Note that on an unnumbered link, this may\n            not be a member of any subnet on the system.')
rip2PeerDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 2), RouteTag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerDomain.setDescription('The value in the Routing Domain field  in  RIP\n           packets received from the peer.  As domain suuport\n           is deprecated, this must be zero.')
rip2PeerLastUpdate = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 3), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerLastUpdate.setDescription('The value of sysUpTime when the most recent\n           RIP update was received from this system.')
rip2PeerVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerVersion.setDescription('The RIP version number in the header of the\n           last RIP packet received.')
rip2PeerRcvBadPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerRcvBadPackets.setDescription('The number of RIP response packets from this\n           peer discarded as invalid.')
rip2PeerRcvBadRoutes = MibTableColumn((1, 3, 6, 1, 2, 1, 23, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rip2PeerRcvBadRoutes.setDescription('The number of routes from this peer that were\n           ignored because the entry format was invalid.')
rip2Conformance = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5))
rip2Groups = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5, 1))
rip2Compliances = MibIdentifier((1, 3, 6, 1, 2, 1, 23, 5, 2))
rip2Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 23, 5, 2, 1)).setObjects(*(("RIPv2-MIB", "rip2GlobalGroup"), ("RIPv2-MIB", "rip2IfStatGroup"), ("RIPv2-MIB", "rip2IfConfGroup"), ("RIPv2-MIB", "rip2PeerGroup"),))
if mibBuilder.loadTexts: rip2Compliance.setDescription('The compliance statement ')
rip2GlobalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 1)).setObjects(*(("RIPv2-MIB", "rip2GlobalRouteChanges"), ("RIPv2-MIB", "rip2GlobalQueries"),))
if mibBuilder.loadTexts: rip2GlobalGroup.setDescription('This group defines global controls for RIP-II systems.')
rip2IfStatGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 2)).setObjects(*(("RIPv2-MIB", "rip2IfStatAddress"), ("RIPv2-MIB", "rip2IfStatRcvBadPackets"), ("RIPv2-MIB", "rip2IfStatRcvBadRoutes"), ("RIPv2-MIB", "rip2IfStatSentUpdates"), ("RIPv2-MIB", "rip2IfStatStatus"),))
if mibBuilder.loadTexts: rip2IfStatGroup.setDescription('This group defines interface statistics for RIP-II systems.')
rip2IfConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 3)).setObjects(*(("RIPv2-MIB", "rip2IfConfAddress"), ("RIPv2-MIB", "rip2IfConfAuthType"), ("RIPv2-MIB", "rip2IfConfAuthKey"), ("RIPv2-MIB", "rip2IfConfSend"), ("RIPv2-MIB", "rip2IfConfReceive"), ("RIPv2-MIB", "rip2IfConfDefaultMetric"), ("RIPv2-MIB", "rip2IfConfStatus"), ("RIPv2-MIB", "rip2IfConfSrcAddress"),))
if mibBuilder.loadTexts: rip2IfConfGroup.setDescription('This group defines interface configuration for RIP-II systems.')
rip2PeerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 23, 5, 1, 4)).setObjects(*(("RIPv2-MIB", "rip2PeerAddress"), ("RIPv2-MIB", "rip2PeerDomain"), ("RIPv2-MIB", "rip2PeerLastUpdate"), ("RIPv2-MIB", "rip2PeerVersion"), ("RIPv2-MIB", "rip2PeerRcvBadPackets"), ("RIPv2-MIB", "rip2PeerRcvBadRoutes"),))
if mibBuilder.loadTexts: rip2PeerGroup.setDescription('This group defines peer information for RIP-II systems.')
mibBuilder.exportSymbols("RIPv2-MIB", rip2IfStatSentUpdates=rip2IfStatSentUpdates, RouteTag=RouteTag, rip2IfConfAuthType=rip2IfConfAuthType, rip2IfStatStatus=rip2IfStatStatus, rip2IfStatEntry=rip2IfStatEntry, rip2PeerDomain=rip2PeerDomain, rip2IfStatRcvBadPackets=rip2IfStatRcvBadPackets, rip2Globals=rip2Globals, rip2IfConfStatus=rip2IfConfStatus, rip2IfConfAddress=rip2IfConfAddress, rip2IfStatAddress=rip2IfStatAddress, rip2PeerAddress=rip2PeerAddress, rip2PeerLastUpdate=rip2PeerLastUpdate, rip2PeerTable=rip2PeerTable, rip2PeerRcvBadRoutes=rip2PeerRcvBadRoutes, rip2PeerGroup=rip2PeerGroup, rip2IfConfEntry=rip2IfConfEntry, rip2PeerEntry=rip2PeerEntry, rip2Compliance=rip2Compliance, rip2IfConfSend=rip2IfConfSend, rip2IfConfDomain=rip2IfConfDomain, rip2IfStatGroup=rip2IfStatGroup, rip2PeerRcvBadPackets=rip2PeerRcvBadPackets, rip2PeerVersion=rip2PeerVersion, rip2Groups=rip2Groups, rip2IfConfAuthKey=rip2IfConfAuthKey, rip2GlobalQueries=rip2GlobalQueries, rip2IfConfSrcAddress=rip2IfConfSrcAddress, rip2IfStatRcvBadRoutes=rip2IfStatRcvBadRoutes, rip2IfConfReceive=rip2IfConfReceive, rip2=rip2, rip2IfStatTable=rip2IfStatTable, rip2GlobalGroup=rip2GlobalGroup, rip2IfConfTable=rip2IfConfTable, PYSNMP_MODULE_ID=rip2, rip2Compliances=rip2Compliances, rip2IfConfDefaultMetric=rip2IfConfDefaultMetric, rip2IfConfGroup=rip2IfConfGroup, rip2GlobalRouteChanges=rip2GlobalRouteChanges, rip2Conformance=rip2Conformance)



#
# PySNMP MIB module IPMROUTE-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPMROUTE-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( IANAipMRouteProtocol, IANAipRouteProtocol, ) = mibBuilder.importSymbols("IANA-RTPROTO-MIB", "IANAipMRouteProtocol", "IANAipRouteProtocol")
( InterfaceIndexOrZero, InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero", "InterfaceIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( mib_2, TimeTicks, ModuleIdentity, Integer32, Counter32, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, Unsigned32, MibIdentifier, Gauge32, Counter64, Bits, NotificationType, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "mib-2", "TimeTicks", "ModuleIdentity", "Integer32", "Counter32", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity", "Unsigned32", "MibIdentifier", "Gauge32", "Counter64", "Bits", "NotificationType", "IpAddress")
( RowStatus, DisplayString, TruthValue, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "DisplayString", "TruthValue", "TextualConvention")
ipMRouteStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 83)).setRevisions(("2000-09-22 00:00",))
if mibBuilder.loadTexts: ipMRouteStdMIB.setLastUpdated('200009220000Z')
if mibBuilder.loadTexts: ipMRouteStdMIB.setOrganization('IETF IDMR Working Group')
if mibBuilder.loadTexts: ipMRouteStdMIB.setContactInfo(' Dave Thaler\n              Microsoft Corporation\n              One Microsoft Way\n              Redmond, WA  98052-6399\n              US\n\n              Phone: +1 425 703 8835\n              EMail: dthaler@microsoft.com')
if mibBuilder.loadTexts: ipMRouteStdMIB.setDescription('The MIB module for management of IP Multicast routing, but\n            independent of the specific multicast routing protocol in\n            use.')
class LanguageTag(OctetString, TextualConvention):
    displayHint = '100a'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,100)

ipMRouteMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 83, 1))
ipMRoute = MibIdentifier((1, 3, 6, 1, 2, 1, 83, 1, 1))
ipMRouteEnable = MibScalar((1, 3, 6, 1, 2, 1, 83, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipMRouteEnable.setDescription('The enabled status of IP Multicast routing on this router.')
ipMRouteEntryCount = MibScalar((1, 3, 6, 1, 2, 1, 83, 1, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteEntryCount.setDescription('The number of rows in the ipMRouteTable.  This can be used\n            to monitor the multicast routing table size.')
ipMRouteTable = MibTable((1, 3, 6, 1, 2, 1, 83, 1, 1, 2), )
if mibBuilder.loadTexts: ipMRouteTable.setDescription('The (conceptual) table containing multicast routing\n            information for IP datagrams sent by particular sources to\n            the IP multicast groups known to this router.')
ipMRouteEntry = MibTableRow((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteGroup"), (0, "IPMROUTE-STD-MIB", "ipMRouteSource"), (0, "IPMROUTE-STD-MIB", "ipMRouteSourceMask"))
if mibBuilder.loadTexts: ipMRouteEntry.setDescription('An entry (conceptual row) containing the multicast routing\n            information for IP datagrams from a particular source and\n            addressed to a particular IP multicast group address.\n            Discontinuities in counters in this entry can be detected by\n            observing the value of ipMRouteUpTime.')
ipMRouteGroup = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 1), IpAddress())
if mibBuilder.loadTexts: ipMRouteGroup.setDescription('The IP multicast group address for which this entry\n            contains multicast routing information.')
ipMRouteSource = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 2), IpAddress())
if mibBuilder.loadTexts: ipMRouteSource.setDescription('The network address which when combined with the\n            corresponding value of ipMRouteSourceMask identifies the\n            sources for which this entry contains multicast routing\n            information.')
ipMRouteSourceMask = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 3), IpAddress())
if mibBuilder.loadTexts: ipMRouteSourceMask.setDescription('The network mask which when combined with the corresponding\n            value of ipMRouteSource identifies the sources for which\n            this entry contains multicast routing information.')
ipMRouteUpstreamNeighbor = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 4), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteUpstreamNeighbor.setDescription('The address of the upstream neighbor (e.g., RPF neighbor)\n            from which IP datagrams from these sources to this multicast\n            address are received, or 0.0.0.0 if the upstream neighbor is\n            unknown (e.g., in CBT).')
ipMRouteInIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 5), InterfaceIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInIfIndex.setDescription('The value of ifIndex for the interface on which IP\n            datagrams sent by these sources to this multicast address\n            are received.  A value of 0 indicates that datagrams are not\n            subject to an incoming interface check, but may be accepted\n            on multiple interfaces (e.g., in CBT).')
ipMRouteUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 6), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteUpTime.setDescription('The time since the multicast routing information\n            represented by this entry was learned by the router.')
ipMRouteExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 7), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteExpiryTime.setDescription('The minimum amount of time remaining before this entry will\n            be aged out.  The value 0 indicates that the entry is not\n            subject to aging.')
ipMRoutePkts = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRoutePkts.setDescription('The number of packets which this router has received from\n            these sources and addressed to this multicast group\n            address.')
ipMRouteDifferentInIfPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteDifferentInIfPackets.setDescription('The number of packets which this router has received from\n            these sources and addressed to this multicast group address,\n            which were dropped because they were not received on the\n            interface indicated by ipMRouteInIfIndex.  Packets which are\n            not subject to an incoming interface check (e.g., using CBT)\n            are not counted.')
ipMRouteOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteOctets.setDescription('The number of octets contained in IP datagrams which were\n            received from these sources and addressed to this multicast\n            group address, and which were forwarded by this router.')
ipMRouteProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 11), IANAipMRouteProtocol()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteProtocol.setDescription('The multicast routing protocol via which this multicast\n            forwarding entry was learned.')
ipMRouteRtProto = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 12), IANAipRouteProtocol()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteRtProto.setDescription('The routing mechanism via which the route used to find the\n            upstream or parent interface for this multicast forwarding\n            entry was learned.  Inclusion of values for routing\n            protocols is not intended to imply that those protocols need\n            be supported.')
ipMRouteRtAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 13), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteRtAddress.setDescription('The address portion of the route used to find the upstream\n            or parent interface for this multicast forwarding entry.')
ipMRouteRtMask = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 14), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteRtMask.setDescription('The mask associated with the route used to find the upstream\n            or parent interface for this multicast forwarding entry.')
ipMRouteRtType = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("unicast", 1), ("multicast", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteRtType.setDescription('The reason the given route was placed in the (logical)\n            multicast Routing Information Base (RIB).  A value of\n            unicast means that the route would normally be placed only\n            in the unicast RIB, but was placed in the multicast RIB\n            (instead or in addition) due to local configuration, such as\n            when running PIM over RIP.  A value of multicast means that\n\n\n\n\n\n            the route was explicitly added to the multicast RIB by the\n            routing protocol, such as DVMRP or Multiprotocol BGP.')
ipMRouteHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 2, 1, 16), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteHCOctets.setDescription('The number of octets contained in IP datagrams which were\n            received from these sources and addressed to this multicast\n            group address, and which were forwarded by this router.\n            This object is a 64-bit version of ipMRouteOctets.')
ipMRouteNextHopTable = MibTable((1, 3, 6, 1, 2, 1, 83, 1, 1, 3), )
if mibBuilder.loadTexts: ipMRouteNextHopTable.setDescription('The (conceptual) table containing information on the next-\n            hops on outgoing interfaces for routing IP multicast\n            datagrams.  Each entry is one of a list of next-hops on\n            outgoing interfaces for particular sources sending to a\n            particular multicast group address.')
ipMRouteNextHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteNextHopGroup"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopSource"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopSourceMask"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopIfIndex"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopAddress"))
if mibBuilder.loadTexts: ipMRouteNextHopEntry.setDescription('An entry (conceptual row) in the list of next-hops on\n            outgoing interfaces to which IP multicast datagrams from\n            particular sources to a IP multicast group address are\n            routed.  Discontinuities in counters in this entry can be\n            detected by observing the value of ipMRouteUpTime.')
ipMRouteNextHopGroup = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 1), IpAddress())
if mibBuilder.loadTexts: ipMRouteNextHopGroup.setDescription('The IP multicast group for which this entry specifies a\n            next-hop on an outgoing interface.')
ipMRouteNextHopSource = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 2), IpAddress())
if mibBuilder.loadTexts: ipMRouteNextHopSource.setDescription('The network address which when combined with the\n            corresponding value of ipMRouteNextHopSourceMask identifies\n            the sources for which this entry specifies a next-hop on an\n            outgoing interface.')
ipMRouteNextHopSourceMask = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 3), IpAddress())
if mibBuilder.loadTexts: ipMRouteNextHopSourceMask.setDescription('The network mask which when combined with the corresponding\n            value of ipMRouteNextHopSource identifies the sources for\n            which this entry specifies a next-hop on an outgoing\n            interface.')
ipMRouteNextHopIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 4), InterfaceIndex())
if mibBuilder.loadTexts: ipMRouteNextHopIfIndex.setDescription('The ifIndex value of the interface for the outgoing\n            interface for this next-hop.')
ipMRouteNextHopAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 5), IpAddress())
if mibBuilder.loadTexts: ipMRouteNextHopAddress.setDescription('The address of the next-hop specific to this entry.  For\n            most interfaces, this is identical to ipMRouteNextHopGroup.\n            NBMA interfaces, however, may have multiple next-hop\n            addresses out a single outgoing interface.')
ipMRouteNextHopState = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("pruned", 1), ("forwarding", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopState.setDescription("An indication of whether the outgoing interface and next-\n            hop represented by this entry is currently being used to\n            forward IP datagrams.  The value 'forwarding' indicates it\n            is currently being used; the value 'pruned' indicates it is\n            not.")
ipMRouteNextHopUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 7), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopUpTime.setDescription('The time since the multicast routing information\n            represented by this entry was learned by the router.')
ipMRouteNextHopExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopExpiryTime.setDescription('The minimum amount of time remaining before this entry will\n            be aged out.  If ipMRouteNextHopState is pruned(1), the\n            remaining time until the prune expires and the state reverts\n            to forwarding(2).  Otherwise, the remaining time until this\n            entry is removed from the table.  The time remaining may be\n            copied from ipMRouteExpiryTime if the protocol in use for\n            this entry does not specify next-hop timers.  The value 0\n\n\n\n\n\n            indicates that the entry is not subject to aging.')
ipMRouteNextHopClosestMemberHops = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 9), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopClosestMemberHops.setDescription('The minimum number of hops between this router and any\n            member of this IP multicast group reached via this next-hop\n            on this outgoing interface.  Any IP multicast datagrams for\n            the group which have a TTL less than this number of hops\n            will not be forwarded to this next-hop.')
ipMRouteNextHopProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 10), IANAipMRouteProtocol()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopProtocol.setDescription('The routing mechanism via which this next-hop was learned.')
ipMRouteNextHopPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 3, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteNextHopPkts.setDescription('The number of packets which have been forwarded using this\n            route.')
ipMRouteInterfaceTable = MibTable((1, 3, 6, 1, 2, 1, 83, 1, 1, 4), )
if mibBuilder.loadTexts: ipMRouteInterfaceTable.setDescription('The (conceptual) table containing multicast routing\n            information specific to interfaces.')
ipMRouteInterfaceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteInterfaceIfIndex"))
if mibBuilder.loadTexts: ipMRouteInterfaceEntry.setDescription('An entry (conceptual row) containing the multicast routing\n            information for a particular interface.')
ipMRouteInterfaceIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: ipMRouteInterfaceIfIndex.setDescription('The ifIndex value of the interface for which this entry\n            contains information.')
ipMRouteInterfaceTtl = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipMRouteInterfaceTtl.setDescription('The datagram TTL threshold for the interface. Any IP\n            multicast datagrams with a TTL less than this threshold will\n            not be forwarded out the interface. The default value of 0\n            means all multicast packets are forwarded out the\n            interface.')
ipMRouteInterfaceProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 3), IANAipMRouteProtocol()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInterfaceProtocol.setDescription('The routing protocol running on this interface.')
ipMRouteInterfaceRateLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipMRouteInterfaceRateLimit.setDescription('The rate-limit, in kilobits per second, of forwarded\n            multicast traffic on the interface.  A rate-limit of 0\n            indicates that no rate limiting is done.')
ipMRouteInterfaceInMcastOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInterfaceInMcastOctets.setDescription('The number of octets of multicast packets that have arrived\n            on the interface, including framing characters.  This object\n            is similar to ifInOctets in the Interfaces MIB, except that\n            only multicast packets are counted.')
ipMRouteInterfaceOutMcastOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInterfaceOutMcastOctets.setDescription('The number of octets of multicast packets that have been\n            sent on the interface.')
ipMRouteInterfaceHCInMcastOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 7), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInterfaceHCInMcastOctets.setDescription('The number of octets of multicast packets that have arrived\n            on the interface, including framing characters.  This object\n            is a 64-bit version of ipMRouteInterfaceInMcastOctets.  It\n            is similar to ifHCInOctets in the Interfaces MIB, except\n            that only multicast packets are counted.')
ipMRouteInterfaceHCOutMcastOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 4, 1, 8), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipMRouteInterfaceHCOutMcastOctets.setDescription('The number of octets of multicast packets that have been\n\n\n\n\n\n            sent on the interface.  This object is a 64-bit version of\n            ipMRouteInterfaceOutMcastOctets.')
ipMRouteBoundaryTable = MibTable((1, 3, 6, 1, 2, 1, 83, 1, 1, 5), )
if mibBuilder.loadTexts: ipMRouteBoundaryTable.setDescription("The (conceptual) table listing the router's scoped\n            multicast address boundaries.")
ipMRouteBoundaryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 83, 1, 1, 5, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteBoundaryIfIndex"), (0, "IPMROUTE-STD-MIB", "ipMRouteBoundaryAddress"), (0, "IPMROUTE-STD-MIB", "ipMRouteBoundaryAddressMask"))
if mibBuilder.loadTexts: ipMRouteBoundaryEntry.setDescription('An entry (conceptual row) in the ipMRouteBoundaryTable\n            representing a scoped boundary.')
ipMRouteBoundaryIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 5, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: ipMRouteBoundaryIfIndex.setDescription('The IfIndex value for the interface to which this boundary\n            applies.  Packets with a destination address in the\n            associated address/mask range will not be forwarded out this\n            interface.')
ipMRouteBoundaryAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 5, 1, 2), IpAddress())
if mibBuilder.loadTexts: ipMRouteBoundaryAddress.setDescription('The group address which when combined with the\n            corresponding value of ipMRouteBoundaryAddressMask\n            identifies the group range for which the scoped boundary\n            exists.  Scoped addresses must come from the range 239.x.x.x\n            as specified in RFC 2365.')
ipMRouteBoundaryAddressMask = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 5, 1, 3), IpAddress())
if mibBuilder.loadTexts: ipMRouteBoundaryAddressMask.setDescription('The group address mask which when combined with the\n            corresponding value of ipMRouteBoundaryAddress identifies\n            the group range for which the scoped boundary exists.')
ipMRouteBoundaryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 5, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipMRouteBoundaryStatus.setDescription('The status of this row, by which new entries may be\n            created, or old entries deleted from this table.')
ipMRouteScopeNameTable = MibTable((1, 3, 6, 1, 2, 1, 83, 1, 1, 6), )
if mibBuilder.loadTexts: ipMRouteScopeNameTable.setDescription('The (conceptual) table listing the multicast scope names.')
ipMRouteScopeNameEntry = MibTableRow((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteScopeNameAddress"), (0, "IPMROUTE-STD-MIB", "ipMRouteScopeNameAddressMask"), (1, "IPMROUTE-STD-MIB", "ipMRouteScopeNameLanguage"))
if mibBuilder.loadTexts: ipMRouteScopeNameEntry.setDescription('An entry (conceptual row) in the ipMRouteScopeNameTable\n            representing a multicast scope name.')
ipMRouteScopeNameAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 1), IpAddress())
if mibBuilder.loadTexts: ipMRouteScopeNameAddress.setDescription('The group address which when combined with the\n            corresponding value of ipMRouteScopeNameAddressMask\n            identifies the group range associated with the multicast\n            scope.  Scoped addresses must come from the range\n            239.x.x.x.')
ipMRouteScopeNameAddressMask = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 2), IpAddress())
if mibBuilder.loadTexts: ipMRouteScopeNameAddressMask.setDescription('The group address mask which when combined with the\n            corresponding value of ipMRouteScopeNameAddress identifies\n            the group range associated with the multicast scope.')
ipMRouteScopeNameLanguage = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 3), LanguageTag())
if mibBuilder.loadTexts: ipMRouteScopeNameLanguage.setDescription('The RFC 1766-style language tag associated with the scope\n            name.')
ipMRouteScopeNameString = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 4), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipMRouteScopeNameString.setDescription('The textual name associated with the multicast scope.  The\n            value of this object should be suitable for displaying to\n            end-users, such as when allocating a multicast address in\n            this scope.  When no name is specified, the default value of\n            this object should be the string 239.x.x.x/y with x and y\n            replaced appropriately to describe the address and mask\n            length associated with the scope.')
ipMRouteScopeNameDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 5), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipMRouteScopeNameDefault.setDescription('If true, indicates a preference that the name in the\n            following language should be used by applications if no name\n            is available in a desired language.')
ipMRouteScopeNameStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 83, 1, 1, 6, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipMRouteScopeNameStatus.setDescription('The status of this row, by which new entries may be\n            created, or old entries deleted from this table.')
ipMRouteMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 83, 2))
ipMRouteMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 83, 2, 1))
ipMRouteMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 83, 2, 2))
ipMRouteMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 83, 2, 1, 1)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteMIBBasicGroup"), ("IPMROUTE-STD-MIB", "ipMRouteMIBRouteGroup"), ("IPMROUTE-STD-MIB", "ipMRouteMIBBoundaryGroup"), ("IPMROUTE-STD-MIB", "ipMRouteMIBHCInterfaceGroup"),))
if mibBuilder.loadTexts: ipMRouteMIBCompliance.setDescription('The compliance statement for the IP Multicast MIB.')
ipMRouteMIBBasicGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 1)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteEnable"), ("IPMROUTE-STD-MIB", "ipMRouteEntryCount"), ("IPMROUTE-STD-MIB", "ipMRouteUpstreamNeighbor"), ("IPMROUTE-STD-MIB", "ipMRouteInIfIndex"), ("IPMROUTE-STD-MIB", "ipMRouteUpTime"), ("IPMROUTE-STD-MIB", "ipMRouteExpiryTime"), ("IPMROUTE-STD-MIB", "ipMRouteNextHopState"), ("IPMROUTE-STD-MIB", "ipMRouteNextHopUpTime"), ("IPMROUTE-STD-MIB", "ipMRouteNextHopExpiryTime"), ("IPMROUTE-STD-MIB", "ipMRouteNextHopProtocol"), ("IPMROUTE-STD-MIB", "ipMRouteNextHopPkts"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceTtl"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceProtocol"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceRateLimit"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceInMcastOctets"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceOutMcastOctets"), ("IPMROUTE-STD-MIB", "ipMRouteProtocol"),))
if mibBuilder.loadTexts: ipMRouteMIBBasicGroup.setDescription('A collection of objects to support basic management of IP\n            Multicast routing.')
ipMRouteMIBHopCountGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 2)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteNextHopClosestMemberHops"),))
if mibBuilder.loadTexts: ipMRouteMIBHopCountGroup.setDescription('A collection of objects to support management of the use of\n            hop counts in IP Multicast routing.')
ipMRouteMIBBoundaryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 3)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteBoundaryStatus"), ("IPMROUTE-STD-MIB", "ipMRouteScopeNameString"), ("IPMROUTE-STD-MIB", "ipMRouteScopeNameDefault"), ("IPMROUTE-STD-MIB", "ipMRouteScopeNameStatus"),))
if mibBuilder.loadTexts: ipMRouteMIBBoundaryGroup.setDescription('A collection of objects to support management of scoped\n            multicast address boundaries.')
ipMRouteMIBPktsOutGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 4)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteNextHopPkts"),))
if mibBuilder.loadTexts: ipMRouteMIBPktsOutGroup.setDescription('A collection of objects to support management of packet\n            counters for each outgoing interface entry of a route.')
ipMRouteMIBHCInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 5)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteInterfaceHCInMcastOctets"), ("IPMROUTE-STD-MIB", "ipMRouteInterfaceHCOutMcastOctets"), ("IPMROUTE-STD-MIB", "ipMRouteHCOctets"),))
if mibBuilder.loadTexts: ipMRouteMIBHCInterfaceGroup.setDescription('A collection of objects providing information specific to\n            high speed (greater than 20,000,000 bits/second) network\n            interfaces.')
ipMRouteMIBRouteGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 6)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRouteRtProto"), ("IPMROUTE-STD-MIB", "ipMRouteRtAddress"), ("IPMROUTE-STD-MIB", "ipMRouteRtMask"), ("IPMROUTE-STD-MIB", "ipMRouteRtType"),))
if mibBuilder.loadTexts: ipMRouteMIBRouteGroup.setDescription('A collection of objects providing information on the\n            relationship between multicast routing information, and the\n            IP Forwarding Table.')
ipMRouteMIBPktsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 83, 2, 2, 7)).setObjects(*(("IPMROUTE-STD-MIB", "ipMRoutePkts"), ("IPMROUTE-STD-MIB", "ipMRouteDifferentInIfPackets"), ("IPMROUTE-STD-MIB", "ipMRouteOctets"),))
if mibBuilder.loadTexts: ipMRouteMIBPktsGroup.setDescription('A collection of objects to support management of packet\n            counters for each forwarding entry.')
mibBuilder.exportSymbols("IPMROUTE-STD-MIB", ipMRouteMIBConformance=ipMRouteMIBConformance, ipMRouteMIBPktsGroup=ipMRouteMIBPktsGroup, ipMRouteEntryCount=ipMRouteEntryCount, LanguageTag=LanguageTag, ipMRouteHCOctets=ipMRouteHCOctets, ipMRouteNextHopUpTime=ipMRouteNextHopUpTime, ipMRouteScopeNameTable=ipMRouteScopeNameTable, ipMRouteMIBBasicGroup=ipMRouteMIBBasicGroup, ipMRoutePkts=ipMRoutePkts, ipMRouteNextHopSource=ipMRouteNextHopSource, ipMRouteInterfaceRateLimit=ipMRouteInterfaceRateLimit, ipMRouteScopeNameDefault=ipMRouteScopeNameDefault, ipMRouteNextHopClosestMemberHops=ipMRouteNextHopClosestMemberHops, ipMRouteScopeNameAddress=ipMRouteScopeNameAddress, ipMRouteRtProto=ipMRouteRtProto, ipMRouteNextHopProtocol=ipMRouteNextHopProtocol, ipMRouteTable=ipMRouteTable, ipMRouteNextHopExpiryTime=ipMRouteNextHopExpiryTime, ipMRouteRtType=ipMRouteRtType, ipMRouteScopeNameEntry=ipMRouteScopeNameEntry, ipMRouteRtAddress=ipMRouteRtAddress, ipMRouteScopeNameString=ipMRouteScopeNameString, ipMRouteInterfaceProtocol=ipMRouteInterfaceProtocol, ipMRouteMIBCompliances=ipMRouteMIBCompliances, ipMRouteBoundaryTable=ipMRouteBoundaryTable, ipMRouteScopeNameStatus=ipMRouteScopeNameStatus, ipMRouteGroup=ipMRouteGroup, ipMRouteNextHopTable=ipMRouteNextHopTable, ipMRouteSource=ipMRouteSource, ipMRouteMIBHopCountGroup=ipMRouteMIBHopCountGroup, ipMRouteEntry=ipMRouteEntry, PYSNMP_MODULE_ID=ipMRouteStdMIB, ipMRouteExpiryTime=ipMRouteExpiryTime, ipMRouteBoundaryAddress=ipMRouteBoundaryAddress, ipMRouteMIBPktsOutGroup=ipMRouteMIBPktsOutGroup, ipMRouteSourceMask=ipMRouteSourceMask, ipMRouteNextHopSourceMask=ipMRouteNextHopSourceMask, ipMRouteInIfIndex=ipMRouteInIfIndex, ipMRouteScopeNameLanguage=ipMRouteScopeNameLanguage, ipMRouteOctets=ipMRouteOctets, ipMRouteNextHopPkts=ipMRouteNextHopPkts, ipMRouteNextHopAddress=ipMRouteNextHopAddress, ipMRouteNextHopState=ipMRouteNextHopState, ipMRouteMIBRouteGroup=ipMRouteMIBRouteGroup, ipMRouteBoundaryAddressMask=ipMRouteBoundaryAddressMask, ipMRouteRtMask=ipMRouteRtMask, ipMRouteInterfaceInMcastOctets=ipMRouteInterfaceInMcastOctets, ipMRouteBoundaryIfIndex=ipMRouteBoundaryIfIndex, ipMRouteProtocol=ipMRouteProtocol, ipMRouteNextHopIfIndex=ipMRouteNextHopIfIndex, ipMRouteMIBHCInterfaceGroup=ipMRouteMIBHCInterfaceGroup, ipMRouteDifferentInIfPackets=ipMRouteDifferentInIfPackets, ipMRouteInterfaceHCInMcastOctets=ipMRouteInterfaceHCInMcastOctets, ipMRouteNextHopEntry=ipMRouteNextHopEntry, ipMRouteInterfaceHCOutMcastOctets=ipMRouteInterfaceHCOutMcastOctets, ipMRouteBoundaryStatus=ipMRouteBoundaryStatus, ipMRouteEnable=ipMRouteEnable, ipMRouteMIBCompliance=ipMRouteMIBCompliance, ipMRouteInterfaceOutMcastOctets=ipMRouteInterfaceOutMcastOctets, ipMRouteNextHopGroup=ipMRouteNextHopGroup, ipMRouteInterfaceIfIndex=ipMRouteInterfaceIfIndex, ipMRouteInterfaceEntry=ipMRouteInterfaceEntry, ipMRouteStdMIB=ipMRouteStdMIB, ipMRouteInterfaceTable=ipMRouteInterfaceTable, ipMRouteUpstreamNeighbor=ipMRouteUpstreamNeighbor, ipMRouteUpTime=ipMRouteUpTime, ipMRouteScopeNameAddressMask=ipMRouteScopeNameAddressMask, ipMRoute=ipMRoute, ipMRouteInterfaceTtl=ipMRouteInterfaceTtl, ipMRouteMIBBoundaryGroup=ipMRouteMIBBoundaryGroup, ipMRouteMIBObjects=ipMRouteMIBObjects, ipMRouteBoundaryEntry=ipMRouteBoundaryEntry, ipMRouteMIBGroups=ipMRouteMIBGroups)
